#
# spec file for package gtk-gnutella
#
# Copyright (c) 2023 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#

%define _lto_cflags %{nil}

Name:           gtk-gnutella
Version:        1.2.2
Release:        1699.1.pm.82
Summary:        Gnutella Peer to Peer Client
License:        GPL-2.0-or-later
Url:            http://gtk-gnutella.sourceforge.net/
Source:         https://sourceforge.net/projects/gtk-gnutella/files/%{name}/%{version}/%{name}-%{version}.tar.xz
Patch0:         gtk-gnutella.enum-msg.patch
BuildRequires:  dbus-1-glib-devel
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnutls) >= 3.2.4
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(zlib)

%description
Gtk-Gnutella is a full-featured Gnutella client using GTK+. It contains all
widely deployed Gnutella features, including DHT support. It is extremely
efficient, using little CPU time and memory. It is meant to be left running
24x7. It is fully compatible with UPnP and NAT-PMP, and as such is easy to use
behind a firewall supporting one of these port mapping technologies.

%prep
%autosetup -p1

%build
./build.sh \
    --gtk2 \
    --prefix="%{_prefix}" \
    --bindir="%{_bindir}" \
    --datadir="%{_datadir}/%{name}" \
    --libdir="%{_libdir}" \
    --localedir="%{_datadir}/locale" \
    --mandir="%{_mandir}" \
    --cc="gcc" \
    --cflags="%{optflags}" \
    --cppflags="%{optflags}" \
    --make="make" \
    --configure-only \
    --verbose

%make_build

%install
%make_install INSTALL_PREFIX=%{buildroot}
rm "%{buildroot}%{_libdir}"/*.nm

%fdupes -s '%{buildroot}'

%suse_update_desktop_file -r "%{name}" Network FileTransfer

%find_lang "%{name}"

%files -f "%{name}.lang"
%doc ChangeLog README
%license GEO_LICENSE LICENSE
%{_bindir}/gtk-gnutella
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata
%{_datadir}/pixmaps/%{name}.*

%changelog
* Wed Mar 29 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.2.2
  Improvements:
  * Extended "props" shell command with -e (exact) and -i
    (ignore missing).
  * The "props" command now takes a set of properties, handled
    as one batch.
  Bug Fixes:
  * Properly recompute bandwidth stealing on DHT changes.
  * Avoid crashing in D-Bus lib when filename is improperly
    UTF-8 encoded.
  * DHT: protect against corrupted database.
  * bw_available(): fix invalid logic for I/O source capping.
  * pong_all_neighbours_but_one(): iterate on local list.
  * dq_node_removed(): must free dq object asynchronously.
  Under the Hood:
  * Update IRC network information: moved from freenode to
    libera.chat
  * Chunk size limiting for uploads accounts for bandwidth.
  * Reduce memory footprint for statx_t if no data kept.
  * CQ: defer freeing of dispatched event.
  * watchdog: be more verbose within critical messages.
  * node_parse(): signal to callers when we have BYE-ed the node.
  * cq_event_called(): use better diagnostic on assert failure.
  * dbus_util_send_message(): protect against invalid text.
  * prepare_entry(): ensure entry invariant remains true.
  * wd_expire(): do nothing if watchdog was asleep.
  version 1.2.1:
  Improvements:
  * Show command to clean stale lockfile.
  * Add properties to track bytes exchanged by schedulers.
  * Add -t switch to shell "status" command.
  * Make use of libera.chat instead of freenode.
  * Expiration time now increased from 1 to 2 years.
  * New --no-expire switch to disable GUI popup when expired.
  Bug Fixes:
  * pattern_prefix_period(): don't corrupt end-of-block.
  * Fix subtle recursive resizing bug.
  * Do not emit empty leading description in saved properties.
  * For time sync over UDP, write replying time later!
  * hash_table_resize(): clear last cached lookup!
  * ev_link(): insert events in the proper bucket!
  Under the Hood:
  * Updated GeoIP databases.
  * Ad bit_generic_count_set().
  * Add plural_child().
  * Add progstart_was_called().
  * Add H_STRFREEV_NULL().
  * Add syn=c to *.ht and *.ct files for vim.
  * Add hash_table_copy_foreach().
  * Add tm_precise_elapsed_ns() convenience routine.
  * Add thread_stack_size() to get configured stack size.
  * Add pattern_string() to get the string being looked for.
  * Add str_2c_from() to grab C string from a given offset.
  * Add eval_subst_atom().
  * Add stacktrace_caller_fast() and stack-test program.
  * Add thread_{un}suspend().
  * Add tmalloc_contains() for assertions.
  * Add public VMM validate/invalidate routines.
  * Add macros to ease printing for tmval and tmspec.
  * Add node_check() to node traversal loops.
  * Avoid branches in SIGN() as well.
  * Avoid regeneration of Geo DB if no data changes.
  * Bump python dependency for jhbuild on OSX.
  * Better clock skew computation.
  * Handle time-sync exchanges via UDP better.
  * Make use of travis cache feature for OSX builds.
  * Only include <sys/sysctl.h> if we actually need it.
  * Allow compilation with usemymalloc=n on 32-bit CPUs.
  * Let mem_test() run only once.
  * When no backtrace(), ensure we compile with a frame pointer.
  * Compile with -DTRACK_MALLOC -DREMAP_ZALLOC again.
  * Made -DTRACK_ZALLOC usable again.
  * Do not check stack at longjmp() if on altstack.
  * Do not trap hash_list_{new,free}() under REMAP_ZALLOC.
  * Ensure properties use xmalloc() for their values.
  * Wait until main() starts to allocate the signal chunk.
  * Made ascii_toupper() and ascii_tolower() avoid branching.
  * Trace saving time whithin property files.
  * Trace page (PA) and offset within page on SEGV.
  * Trace page protection on SEGV faults, if possible.
  * Trace how and where symbols were loaded in crash log.
  * Symbol quality definition moved to symbols!
  * Windows: handle freopen("a") specially to allow read sharing.
  * Windows: no need to dump stack again if no gdb.
  * mutex: supply more context on lock errors.
  * ostream: now also accepts str_t as output medium.
  * rwlock: added debug option to track wlock location.
  * random-test: added -a to benchmark all routines.
  * random-test: add -v to be verbose when -a is used.
  * VMM: added extra debugging tools / assertions.
  * VMM: trace new compile-time options.
  * clock: simplify code by using aging table.
  * xmalloc: avoid late page pool creation.
  * xmalloc: extended assertions to detect freelist corruption.
  * zalloc: avoid warnings when compiling with REMAP_ZALLOC.
  * zalloc: with ZONE_SAFE, ensure block tagging never changes!
  * malloc.c: enhanced and fixed some errors with
    multi-threading.
  * malloc.c: huge refactoring and cleanup.
  * aging_destroy(): remove periodic GC before cleanup.
  * bfd_util_init(): avoid warning on bfd_init() call.
  * clock_adjust(): removed MAX_SDEV.
  * clock_adjust(): stop pruning if we keep everything.
  * clock_update(): lowered required amount of data.
  * compat_setjmp(): protect against gone contexts.
  * crash_handler_process(): only call crash_auto_restart() if
    needed.
  * ev_free(): assert event is not linked in queue!
  * ev_unlink(): added list consistency assertions.
  * eval_subst(): remove the size limitation on the susbtituted
    string.
  * evq_close(): be silent if event queue not created.
  * fi_pick_rarest_chunk(): fixed assertion failure.
  * fi_pick_rarest_chunk(): log assertion values.
  * get_prop(): also trace failing property when ps is NULL.
  * ggept_filesize_encode(): can return 0 if given 0.
  * hash_compute_increment(): make it odd without branch.
  * main(): do not set a crash dir if not running for long.
  * name_to_single_host_addr(): use pslist_random().
  * ntp_send_probes(): comment updates, cleanup.
  * once_recursive(): avoid calling stacktrace_function_name().
  * progstart_duplicate(): added assertions.
  * prop_lock(): use macro for locking (hiding lock type).
  * rwlock_deadlocked(): trace write owner if known.
  * spinlock_loop(): document why no memory barrier.
  * statusbar_gui_push_v(): be safe if called early.
  * str_avail(): new implementation and semantics.
  * str_ichar() and str_istr() can now append.
  * strvec_cpy(): was failing when called with cnt=0.
  * thread_id_name_to_buf(): be nicer with negative IDs.
  * thread_lock_waiting_done(): cleanup when no problems.
  * tok_version_valid(): no longer run clock_update().
  * xcopy(): not defined as inlined routine when TRACK_MALLOC.
* Mon Dec 28 2020 olaf@aepfle.de
- Update to 1.2.0
* Sun May  8 2016 aloisio@gmx.com
- Update to 1.1.9
  * Changelog at
    https://github.com/gtk-gnutella/gtk-gnutella/blob/v1.1.9/ChangeLog
- Replaced gtk-gnutella-remove_DATE_from_entropy.patch with
  a sed line
- Spec cleanup
* Sat May  5 2012 seife+obs@b1-systems.com
- update to 0.98.2, see ChangeLog for details
  * this builds again on openSUSE >= 12.1
* Sat Sep 24 2011 pascal.bleser@opensuse.org
- update to 0.97.1:
* Thu Jul 21 2011 pascal.bleser@opensuse.org
- initial version (0.97)
